@@ -12,47 +12,60 @@ def recursive_glob(startpath, filepattern):
     """
     return [
         os.path.join(dirpath, filename)
-            for dirpath, _, filenames in os.walk(startpath)
-            for filename in filenames if fnmatch.fnmatch(filename, filepattern)
+        for dirpath, _, filenames in os.walk(startpath)
+        for filename in filenames
+        if fnmatch.fnmatch(filename, filepattern)
     ]
 
+
 open3 = open
 if sys.version_info < (3, 0):
     import io
+
     open3 = io.open
 
 # loosely from https://packaging.python.org/guides/single-sourcing-package-version/
 HERE = os.path.abspath(os.path.dirname(__file__))
 
-name='pyaedt'
+name = "pyaedt"
 
-with open(os.path.join(HERE, 'pyaedt', 'version.txt'), 'r') as f:
+with open(os.path.join(HERE, "pyaedt", "version.txt"), "r") as f:
     version = f.readline()
 
-author='ANSYS, Inc.'
+author = "ANSYS, Inc."
 
-maintainer='Massimo Capodiferro'
+maintainer = "Massimo Capodiferro"
 
-maintainer_email='massimo.capodiferro@ansys.com'
+maintainer_email = "massimo.capodiferro@ansys.com"
 
-description='Higher-Level Pythonic Ansys Electronics Destkop Framework'
+description = "Higher-Level Pythonic Ansys Electronics Destkop Framework"
 
 # Get the long description from the README file
 with open3(os.path.join(HERE, "README.rst"), encoding="utf-8") as f:
     long_description = f.read()
 
-packages=['pyaedt', 'pyaedt.misc', 'pyaedt.application', 'pyaedt.modeler', 'pyaedt.modules',
-            'pyaedt.generic', 'pyaedt.edb_core', 'pyaedt.examples']
+packages = [
+    "pyaedt",
+    "pyaedt.misc",
+    "pyaedt.application",
+    "pyaedt.modeler",
+    "pyaedt.modules",
+    "pyaedt.generic",
+    "pyaedt.edb_core",
+    "pyaedt.examples",
+]
 
-data_files=[('dlls', recursive_glob(os.path.join('pyaedt', 'dlls'), '*')),
-            ('misc', recursive_glob(os.path.join('pyaedt', 'misc'), '*')),
-            ('License', recursive_glob('.', '*.md')),
-            ('version', ['pyaedt/version.txt']),
-            ('setup-distutils', ['setup-distutils.py'])]
+data_files = [
+    ("dlls", recursive_glob(os.path.join("pyaedt", "dlls"), "*")),
+    ("misc", recursive_glob(os.path.join("pyaedt", "misc"), "*")),
+    ("License", recursive_glob(".", "*.md")),
+    ("version", ["pyaedt/version.txt"]),
+    ("setup-distutils", ["setup-distutils.py"]),
+]
 
-license="MIT"
+license = "MIT"
 
-classifiers=[
+classifiers = [
     "Development Status :: 4 - Beta",
     "Programming Language :: Python :: 2.7",
     "Programming Language :: Python :: 3.6",
