@@ -1,10 +1,6 @@
-from ..generic.general_methods import aedt_exception_handler, generate_unique_name
-from .Analysis import Analysis
-from .Design import solutions_settings, Design
 from ..modeler.Circuit import ModelerEmit
 from ..modules.PostProcessor import PostProcessor
-from ..modules.SetupTemplates import SetupKeys
-from ..modules.SolveSetup import SetupCircuit
+from .Design import Design
 
 
 class FieldAnalysisEmit(Design):
@@ -45,11 +41,32 @@ class FieldAnalysisEmit(Design):
         """Setup names."""
         return []
 
-    def __init__(self, application, projectname, designname, solution_type, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=True, release_on_exit=True, student_version=False):
+    def __init__(
+        self,
+        application,
+        projectname,
+        designname,
+        solution_type,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=True,
+        close_on_exit=True,
+        student_version=False,
+    ):
         self.solution_type = solution_type
-        Design.__init__(self, application, projectname, designname, solution_type,
-                        specified_version, NG, AlwaysNew, release_on_exit, student_version)
+        Design.__init__(
+            self,
+            application,
+            projectname,
+            designname,
+            solution_type,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
         self._modeler = ModelerEmit(self)
         self._post = PostProcessor(self)
 
