@@ -1,6 +1,6 @@
 import os
 
-from pyaedt import _pythonver
+from pyaedt import _pythonver, is_ironpython, inside_desktop
 
 from ..application.Variables import AEDT_units
 from ..edb import Edb
@@ -32,8 +32,11 @@ class Modeler3DLayout(Modeler):
         edb_folder = os.path.join(self._parent.project_path, self._parent.project_name + ".aedb")
         edb_file = os.path.join(edb_folder, "edb.def")
         self._edb = None
-        if os.path.exists(edb_file):
-            self._mttime = os.path.getmtime(edb_file)
+        if os.path.exists(edb_file) or (inside_desktop and is_ironpython):
+            if os.path.exists(edb_file):
+                self._mttime = os.path.getmtime(edb_file)
+            else:
+                self._mttime = 0
             self._edb = Edb(
                 edb_folder,
                 self._parent.design_name,
@@ -64,10 +67,13 @@ class Modeler3DLayout(Modeler):
              EDB.
 
         """
-        if os.name != "posix":
+        if not (inside_desktop and is_ironpython):
             edb_folder = os.path.join(self._parent.project_path, self._parent.project_name + ".aedb")
             edb_file = os.path.join(edb_folder, "edb.def")
-            _mttime = os.path.getmtime(edb_file)
+            if os.path.exists(edb_file):
+                _mttime = os.path.getmtime(edb_file)
+            else:
+                _mttime = 0
             if _mttime != self._mttime:
                 if self._edb:
                     self._edb.close_edb()
@@ -170,11 +176,11 @@ class Modeler3DLayout(Modeler):
 
         Parameters
         ----------
-        object_to_expand: str
+        object_to_expand : str
             Name of the object to expand.
-        size: float, optional
+        size : float, optional
             Size of the expansion. The default is ``1``.
-        expand_type: str, optional
+        expand_type : str, optional
             Type of the expansion. Options are ``"ROUND"``, ``"MITER"``, and
             ``"CORNER"``. The default is ``"ROUND"``.
         replace_original : bool, optional
@@ -425,3 +431,52 @@ class Modeler3DLayout(Modeler):
             ["NAME:options", "count:=", count], ["NAME:elements", ",".join(objectlists)], direction_vector
         )
         return True
+
+    @aedt_exception_handler
+    def set_temperature_dependence(
+            self,
+            include_temperature_dependence=True,
+            enable_feedback=True,
+            ambient_temp=22,
+            create_project_var=False,
+    ):
+        """Set the temperature dependence for the design.
+
+        Parameters
+        ----------
+        include_temperature_dependence : bool, optional
+            Set the temperature setting for the design. The default is ``True``.
+        enable_feedback : bool, optional
+            Enable the feedback. The default is ``True``.
+        ambient_temp : float, optional
+            Ambient temperature. The default is ``22``.
+        create_project_var : bool, optional
+            Whether to create a project variable for the ambient temperature.
+            The default is ``False``. If ``True,`` ``$AmbientTemp`` is created.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        self._messenger.add_info_message("Set the temperature dependence for the design.")
+        if create_project_var:
+            self._parent.variable_manager["$AmbientTemp"] = str(ambient_temp) + "cel"
+            var = "$AmbientTemp"
+        else:
+            var = str(ambient_temp) + "cel"
+        vargs1 = [
+            "NAME:TemperatureSettings",
+            "IncludeTempDependence:=", include_temperature_dependence,
+            "EnableFeedback:=", enable_feedback,
+            "Temperature:=", var,
+        ]
+        try:
+            self.odesign.SetTemperatureSettings(vargs1)
+        except:
+            self._messenger.add_error_message("Failed to enable the temperature dependence.")
+            return False
+        else:
+            self._messenger.add_info_message("Assigned Objects Temperature")
+            return True
