@@ -1,34 +1,38 @@
 """
 This module contains the `Siwave` class.
 
-The `Siwave` module can be initialized as standalone before launching an app or automatically initialized by an app to the latest installed AEDT version.
+The `Siwave` module can be initialized as standalone before launching an app or
+automatically initialized by an app to the latest installed AEDT version.
 
 """
 from __future__ import absolute_import
-from .generic.general_methods import aedt_exception_handler, generate_unique_name
+from .generic.general_methods import aedt_exception_handler
 import os
 import sys
 import pkgutil
+import time
 
 from .misc import list_installed_ansysem
 from pyaedt import is_ironpython, _pythonver
 
 if is_ironpython:
     import clr  # IronPython C:\Program Files\AnsysEM\AnsysEM19.4\Win64\common\IronPython\ipy64.exe
-    _com = 'pythonnet'
+
+    _com = "pythonnet"
     import System
-elif os.name == 'nt':
+elif os.name == "nt":
     modules = [tup[1] for tup in pkgutil.iter_modules()]
-    if 'clr' in modules:
-        import clr
+    if "clr" in modules:
+        import clr  # noqa: F401
         import win32com.client
-        _com = 'pythonnet_v3'
-    elif 'win32com' in modules:
+
+        _com = "pythonnet_v3"
+    elif "win32com" in modules:
         import win32com.client
-        _com = 'pywin32'
+
+        _com = "pywin32"
     else:
-        raise Exception(
-            "Error. No win32com.client or Python.NET modules found. They need to be installed.")
+        raise Exception("Error. No win32com.client or Python.NET modules found. They need to be installed.")
 
 
 # if _pythonver == 3:
@@ -47,6 +51,7 @@ class Siwave:
         the active setup is used or the latest installed version is used.
 
     """
+
     @property
     def version_keys(self):
         """Version keys for AEDT."""
@@ -56,7 +61,7 @@ class Siwave:
 
         version_list = list_installed_ansysem()
         for version_env_var in version_list:
-            current_version_id = version_env_var.replace("ANSYSEM_ROOT", '')
+            current_version_id = version_env_var.replace("ANSYSEM_ROOT", "").replace("ANSYSEMSV_ROOT", "")
             version = int(current_version_id[0:2])
             release = int(current_version_id[2])
             if version < 20:
@@ -75,27 +80,27 @@ class Siwave:
         return self.version_keys[0]
 
     def __init__(self, specified_version=None):
-        self._main = sys.modules['__main__']
-        print ("Launching Siwave Init")
-        if  "oSiwave" in dir(self._main) and self._main.oSiwave is not None:
+        self._main = sys.modules["__main__"]
+        print("Launching Siwave Init")
+        if "oSiwave" in dir(self._main) and self._main.oSiwave is not None:
             self._main.AEDTVersion = self._main.oSiwave.GetVersion()[0:6]
             self._main.oSiwave.RestoreWindow()
-            #self._main.oMessenger = AEDTMessageManager()
+            # self._main.oMessenger = AEDTMessageManager()
             specified_version = self.current_version
-            assert specified_version in self.version_keys, \
-                "Specified version {} not known.".format(specified_version)
+            assert specified_version in self.version_keys, "Specified version {} not known.".format(specified_version)
             version_key = specified_version
             base_path = os.getenv(self._version_ids[specified_version])
             self._main.sDesktopinstallDirectory = base_path
         else:
             if specified_version:
-                assert specified_version in self.version_keys, \
-                    "Specified version {} not known.".format(specified_version)
+                assert specified_version in self.version_keys, "Specified version {} not known.".format(
+                    specified_version
+                )
                 version_key = specified_version
             else:
                 version_key = self.current_version
             base_path = os.getenv(self._version_ids[version_key])
-            self._main = sys.modules['__main__']
+            self._main = sys.modules["__main__"]
             self._main.sDesktopinstallDirectory = base_path
             version = "Siwave.Application." + version_key
             self._main.AEDTVersion = version_key
@@ -104,19 +109,20 @@ class Siwave:
             if "oSiwave" in dir(self._main):
                 del self._main.oSiwave
 
-            if _com == 'pythonnet':
-                self._main.oSiwave = System.Activator.CreateInstance(
-                    System.Type.GetTypeFromProgID(version))
+            if _com == "pythonnet":
+                self._main.oSiwave = System.Activator.CreateInstance(System.Type.GetTypeFromProgID(version))
 
-            elif _com == 'pythonnet_v3': #TODO check if possible to use pythonnet. at the moment the tool open AEDt but doesn't return the wrapper of oApp
-                print("Launching AEDT with Module win32com")
+            elif _com == "pythonnet_v3":
+                # TODO check if possible to use pythonnet. at the moment the tool open AEDt
+                # but doesn't return the wrapper of oApp
+                print("Launching Siwave with Module win32com")
 
-                self._main.oSiwave=win32com.client.Dispatch("Siwave.Application.2021.1")
+                self._main.oSiwave = win32com.client.Dispatch("Siwave.Application.2021.1")
 
             self._main.AEDTVersion = version_key
             self.oSiwave = self._main.oSiwave
             self._main.oSiwave.RestoreWindow()
-            #self._main.oMessenger = AEDTMessageManager()
+            # self._main.oMessenger = AEDTMessageManager()
         self._main.siwave_initialized = True
         self._oproject = self.oSiwave.GetActiveProject()
         pass
@@ -171,7 +177,7 @@ class Siwave:
             Full absolute path and name for the project file.
 
         """
-        return os.path.join(self.project_path, self.project_name + '.siw')
+        return os.path.join(self.project_path, self.project_name + ".siw")
 
     @property
     def lock_file(self):
@@ -183,7 +189,7 @@ class Siwave:
             Full absolute path and name for the project lock file.
 
         """
-        return os.path.join(self.project_path, self.project_name + '.siw.lock')
+        return os.path.join(self.project_path, self.project_name + ".siw.lock")
 
     @property
     def results_directory(self):
@@ -194,7 +200,7 @@ class Siwave:
         str
             Full absolute path to the ``aedtresults`` directory.
         """
-        return os.path.join(self.project_path, self.project_name + '.siwresults')
+        return os.path.join(self.project_path, self.project_name + ".siwresults")
 
     @property
     def src_dir(self):
@@ -216,7 +222,7 @@ class Siwave:
         str
             Full absolute path to the ``pyaedt`` directory.
         """
-        return os.path.realpath(os.path.join(self.src_dir, '..'))
+        return os.path.realpath(os.path.join(self.src_dir, ".."))
 
     @property
     def oproject(self):
@@ -259,11 +265,32 @@ class Siwave:
 
         """
         if projectName and projectpath:
-            self.oproject.ScrSaveProjectAs(os.path.join(projectpath, projectName+".siw"))
+            self.oproject.ScrSaveProjectAs(os.path.join(projectpath, projectName + ".siw"))
         else:
             self.oproject.Save()
         return True
 
+    @aedt_exception_handler
+    def close_project(self, save_project=False):
+        """Close the project.
+
+        Parameters
+        ----------
+        save_project : bool, optional
+            whether to save or not the current project before close it.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        if save_project:
+            self.save_project()
+        self.oproject.ScrCloseProject()
+        self._oproject = None
+        return True
+
     @aedt_exception_handler
     def quit_application(self):
         """Quit the application.
@@ -302,4 +329,6 @@ class Siwave:
         """
         self.oproject.ScrExportDcSimReportScaling("All", "All", -1, -1, False)
         self.oproject.ScrExportDcSimReport(simulation_name, bkground_color, file_path)
+        while not os.path.exists(file_path):
+            time.sleep(0.1)
         return True
